Arguments
par
A vector of values for the parameters which are supposedly optimal.
fval
Function value at parameters par.
ngr
Gradient (possibly estimated) of the function at par.
nHes
Matrix that is supposedly the Hessian at par.
nbm
Number of active masks or bounds on par.
maxfn
Logical TRUE if function is being maximized. Default FALSE.
control
A list of controls for the function, made up of the following items
kkt2tol
A tolerance used for the KKT Hessian check.
ktrace
A logical flag that, if TRUE, displays intermediate information
on the progress of the function. Default is FALSE.